summaryrefslogtreecommitdiffstats
path: root/content/ppapi_plugin
diff options
context:
space:
mode:
Diffstat (limited to 'content/ppapi_plugin')
-rw-r--r--content/ppapi_plugin/broker_process_dispatcher.cc12
-rw-r--r--content/ppapi_plugin/ppapi_broker_main.cc1
2 files changed, 8 insertions, 5 deletions
diff --git a/content/ppapi_plugin/ppapi_broker_main.cc b/content/ppapi_plugin/ppapi_broker_main.cc
index 17cd7b7..8789a61 100644
--- a/content/ppapi_plugin/ppapi_broker_main.cc
+++ b/content/ppapi_plugin/ppapi_broker_main.cc
@@ -24,5 +24,6 @@ int PpapiBrokerMain(const MainFunctionParams& parameters) {
ppapi_broker_process.set_main_thread(new PpapiThread(true)); // Broker.
main_message_loop.Run();
+ DVLOG(1) << "PpapiBrokerMain exiting";
return 0;
}
diff --git a/content/ppapi_plugin/broker_process_dispatcher.cc b/content/ppapi_plugin/broker_process_dispatcher.cc
index b8c31d3..26a7100 100644
--- a/content/ppapi_plugin/broker_process_dispatcher.cc
+++ b/content/ppapi_plugin/broker_process_dispatcher.cc
@@ -8,15 +8,16 @@
namespace {
-class PluginReleaseTask : public Task {
+class BrokerReleaseTask : public Task {
public:
void Run() {
+ DVLOG(1) << "BrokerReleaseTask::Run()";
ChildProcess::current()->ReleaseProcess();
}
};
-// How long we wait before releasing the plugin process.
-const int kPluginReleaseTimeMs = 30 * 1000; // 30 seconds.
+// How long we wait before releasing the broker process.
+const int kBrokerReleaseTimeMs = 30 * 1000; // 30 seconds.
} // namespace
@@ -29,11 +30,12 @@ BrokerProcessDispatcher::BrokerProcessDispatcher(
}
BrokerProcessDispatcher::~BrokerProcessDispatcher() {
+ DVLOG(1) << "BrokerProcessDispatcher::~BrokerProcessDispatcher()";
// Don't free the process right away. This timer allows the child process
// to be re-used if the user rapidly goes to a new page that requires this
// plugin. This is the case for common plugins where they may be used on a
// source and destination page of a navigation. We don't want to tear down
// and re-start processes each time in these cases.
- MessageLoop::current()->PostDelayedTask(FROM_HERE, new PluginReleaseTask(),
- kPluginReleaseTimeMs);
+ MessageLoop::current()->PostDelayedTask(FROM_HERE, new BrokerReleaseTask(),
+ kBrokerReleaseTimeMs);
}